@@ -1,32 +1,5 @@
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright (C) 2008-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2008-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 from __future__ import annotations
 
@@ -93,7 +66,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
             self.addmsg('0001-9', 'failed to open and read file', filename)
             return
 
-        self.debug(f'checking {filename}')
+        self.debug("checking %s", filename)
 
         is_uninstall = filename.suffix == '.uinst'
         lines = content.splitlines()
@@ -213,7 +186,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
         else:
             match = self.RE_DH_JOIN.search(c_rules)
             if match:
-                self.debug(f'Detected use of {match[0]}')
+                self.debug("Detected use of %s", match[0])
                 is_old = bool(match[1])
                 if is_old:
                     self.addmsg('0001-23', 'Consider switchting to "univention-join" debhelper sequence', fn_rules)
@@ -222,7 +195,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
                         package = binary_package['Package']
                         for js in fnlist_joinscripts:
                             if js.stem[2:] == package:
-                                self.debug(f'univention-install-joinscript will take care of {js}')
+                                self.debug("univention-install-joinscript will take care of %s", js)
                                 fnlist_joinscripts[js] = JSS.UNREF
                                 found[js] = found.get(js, 0) + 1
 
@@ -234,7 +207,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
                 for fn in uub.FilteredDirWalkGenerator(debianpath, suffixes=['.umc-modules']):
                     for js in fnlist_joinscripts:
                         if js.stem[2:] == fn.stem:
-                            self.debug(f'{js} installed by dh-umc-module-install')
+                            self.debug("%s installed by dh-umc-module-install", js)
                             found[js] = found.get(js, 0) + 1
                             fnlist_joinscripts[js] = JSS.UNREF
 
@@ -246,9 +219,9 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
                 continue
 
             for js in fnlist_joinscripts:
-                self.debug(f'looking for {js.name} in {fn}')
+                self.debug("looking for %s in %s", js.name, fn)
                 if js.name in content:
-                    self.debug(f'found {js.name} in {fn}')
+                    self.debug("found %s in %s", js.name, fn)
                     found[js] = found.get(js, 0) + 1
 
         for js in fnlist_joinscripts:
@@ -271,7 +244,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
             else:
                 continue
 
-            self.debug(f'loading {fn}')
+            self.debug("loading %s", fn)
             try:
                 content = fn.read_text()
             except OSError:
@@ -280,13 +253,13 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
 
             set_e = self.RE_LINE_CONTAINS_SET_E.search(content)
             if set_e:
-                self.debug(f'found "set -e" in {fn}')
+                self.debug('found "set -e" in %s', fn)
 
             for js in fnlist_joinscripts:
-                self.debug(f'looking for {js.name} in {fn}')
+                self.debug("looking for %s in %s", js.name, fn)
                 if js.name in content:
                     fnlist_joinscripts[js] &= ~bit
-                    self.debug(f'found {js.name} in {fn}')
+                    self.debug("found %s in %s", js.name, fn)
 
                     if set_e:
                         for row, line in enumerate(content.splitlines(), start=1):
