@@ -1,32 +1,5 @@
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright (C) 2008-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2008-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 from __future__ import annotations
 
@@ -59,7 +32,7 @@ if TYPE_CHECKING:
 # 8) check, ob univention-install-config-registry-info in debian/rules vorhanden ist, sofern debian/*.univention-config-registry-variables existiert
 
 #
-# TODO / FIXME
+# TODO: / FIXME
 # - 0004-29: Different (conflicting) packages might provide the same Multifile with different definitions (e.g. univention-samba/etc/smb.conf)
 UcrInfo = dict[str, list[str]]
 
@@ -238,13 +211,13 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
                 elif var not in checks['placeholder']:
                     checks['placeholder'].append(var)
             if checks['placeholder']:
-                self.debug('found UCR placeholder variables in {}\n- {}'.format(fn, '\n- '.join(checks['placeholder'])))
+                self.debug('found UCR placeholder variables in %s\n- %s', fn, '\n- '.join(checks['placeholder']))
 
             match = self.RE_IDENTIFIER.search(content, 0)
             if warning_pos and match:
                 identifier = match[0]
                 pos = match.start()
-                self.debug(f'Identifier "{identifier}" found at {pos}')
+                self.debug('Identifier "%s" found at %s', identifier, pos)
                 if warning_pos < pos:
                     self.addmsg('0004-34', f'UCR warning before file type magic "{identifier}"', fn)
 
@@ -261,7 +234,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
                     if var not in checks['variables']:
                         checks['variables'].append(var)
             if checks['variables']:
-                self.debug('found UCR variables in {}\n- {}'.format(fn, '\n- '.join(checks['variables'])))
+                self.debug('found UCR variables in %s\n- %s', fn, '\n- '.join(checks['variables']))
 
             if checks['headerfound']:
                 #
@@ -272,12 +245,12 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
                     if match[2] != fname:
                         self.addmsg('0004-1', f'Path in UCR header seems to be incorrect.\n      - template filename = /etc/univention/templates/files/{fname}\n      - path in header    = {match[1]}', fn)
 
-        self.debug(f'found conffiles: {conffiles.keys()}')
+        self.debug("found conffiles: %s", conffiles.keys())
 
         return conffiles
 
     def read_ucr(self, fn: Path) -> Iterator[UcrInfo]:
-        self.debug(f'Reading {fn}')
+        self.debug("Reading %s", fn)
         try:
             entry: UcrInfo = {}
             with fn.open() as stream:
@@ -306,7 +279,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
             self.addmsg('0004-27', 'cannot open/read file', fn)
 
     def read_ini(self, fn: Path) -> RawConfigParser:
-        self.debug(f'Reading {fn}')
+        self.debug("Reading %s", fn)
 
         cfg = RawConfigParser(interpolation=None)
         try:
@@ -384,7 +357,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
                 self.read_ini(fn)
             elif fn.suffix == '.univention-config-registry':
                 ucrvfn = fn.with_suffix(".univention-config-registry-variables")
-                self.debug(f'testing {ucrvfn}')
+                self.debug("testing %s", ucrvfn)
                 if not ucrvfn.exists():
                     self.addmsg('0004-24', f'{fn.name} exists but corresponding {ucrvfn} is missing', ucrvfn)
 
@@ -408,7 +381,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
             unique: set[str | tuple[str, str]] = set()
 
             for entry in self.read_ucr(fn):
-                self.debug(f'Entry: {entry}')
+                self.debug("Entry: %s", entry)
 
                 try:
                     typ = entry['Type'][0]
@@ -593,9 +566,9 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
                             self.addmsg('0004-55', f'UCR .info-file may contain globbing pattern instead of regular expression: "{var}"', fn)
                             break
 
-            self.debug(f'Multifiles: {multifiles}')
-            self.debug(f'Subfiles: {subfiles}')
-            self.debug(f'Files: {files}')
+            self.debug("Multifiles: %s", multifiles)
+            self.debug("Subfiles: %s", subfiles)
+            self.debug("Files: %s", files)
             for multifile, subfileentries in subfiles.items():
                 if multifile not in multifiles:
                     self.addmsg('0004-10', f'file contains subfile entry without corresponding multifile entry.\n      - subfile = {subfileentries[0]["Subfile"][0]}\n      - multifile = {multifile}', fn)
@@ -640,7 +613,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
                     except LookupError:
                         obj = objlist['etc/' + shortconffn][0]
             except LookupError:
-                self.debug(f'"{shortconffn}" not found in {objlist.keys()!r}')
+                self.debug('"%s" not found in %r', shortconffn, objlist.keys())
             else:
                 conffnfound = True
                 notregistered: list[str] = []
@@ -686,8 +659,8 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
                     ucrvs = "".join(f"\n\t- {ucrv}" for ucrv in notregistered)
                     if mfn and mfn in all_multifiles:
                         # "Multifile" entry exists ==> obj is a subfile
-                        self.debug(f'cfn = {shortconffn!r}')
-                        self.debug(f'knownvars(mf+sf) = {knownvars!r}')
+                        self.debug("cfn = %r", shortconffn)
+                        self.debug("knownvars(mf+sf) = %r", knownvars)
                         self.addmsg('0004-29', f'template file contains variables that are not registered in multifile or subfile entry:{ucrvs}', fn)
                     else:
                         # no subfile ==> File, Module, Script
