@@ -1,32 +1,5 @@
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright (C) 2008-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2008-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 from __future__ import annotations
 
@@ -79,7 +52,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
                 'uses-remove_ucr_template': False,
                 'uses-remove_ucr_info_file': False,
             }
-            self.debug(f'found {fn}')
+            self.debug("found %s", fn)
 
         #
         # check scripts
@@ -107,7 +80,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
                 line = line.strip()
                 if not line or line.startswith('#'):
                     continue
-                self.debug(f'line: {line}')
+                self.debug("line: %s", line)
                 for cmd in ['univention-directory-manager ', '/usr/sbin/univention-directory-manager ', 'univention-admin ', '/usr/sbin/univention-admin ']:
                     if line.startswith(cmd):
                         checks['udm_calls'] += 1
