@@ -1,32 +1,5 @@
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright (C) 2008-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2008-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 from __future__ import annotations
 
@@ -86,18 +59,18 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
         try:
             self.apt = Cache(memonly=True)
         except Exception as ex:
-            self.debug(f'failed to load APT cache: {ex}')
+            self.debug("failed to load APT cache: %s", ex)
 
     def _scan_script(self, fn: Path) -> set[str]:
         """Find calls to 'univention-install-', 'ucr' and use of 'init-autostart.lib' in file 'fn'."""
         need = set()
-        self.debug(f'Reading {fn}')
+        self.debug("Reading %s", fn)
         try:
             with fn.open() as fd:
                 for line in fd:
                     for (key, (regexp, _pkgs)) in self.DEPS.items():
                         if regexp.search(line):
-                            self.debug(f'Found {key.upper()} in {fn}')
+                            self.debug("Found %s in %s", key.upper(), fn)
                             need.add(key)
         except OSError:
             self.addmsg('0014-0', 'failed to open and read file', fn)
@@ -126,7 +99,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
     def check_package(self, path: Path, section: uub.DebianControlBinary) -> set[str]:
         """Check binary package for dependencies."""
         pkg = section['Package']
-        self.debug(f'Package: {pkg}')
+        self.debug("Package: %s", pkg)
 
         bin_pre_set = section.pre
         bin_deps = bin_pre_set | section.dep
@@ -189,7 +162,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
         if self.path == Path('/'):
             return
         fn_control = self.path / 'debian' / 'control'
-        self.debug(f'Reading {fn_control}')
+        self.debug("Reading %s", fn_control)
         try:
             parser = uub.ParserDebianControl(fn_control)
         except uub.FailedToReadFile:
@@ -232,7 +205,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
         fn_control = path / 'debian' / 'control'
         for cand in self._cand(deps):
             if self.RE_TRANSITIONAL.search(cand.summary or ''):
-                self.addmsg('0014-8', f'depends on transitional package {cand.package.name}', fn_control)
+                self.addmsg('0014-9', f'depends on transitional package {cand.package.name}', fn_control)
 
     def check_essential(self, path: Path, deps: Iterable[str]) -> None:
         fn_control = path / 'debian' / 'control'
@@ -255,6 +228,6 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
                 if not cand:
                     raise LookupError(dep)
             except LookupError as ex:
-                self.debug(f'not found {dep}: {ex}')
+                self.debug("not found %s: %s", dep, ex)
             else:
                 yield cand
