@@ -1,32 +1,5 @@
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright (C) 2008-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2008-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 from __future__ import annotations
 
@@ -154,30 +127,30 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
             '0015-2': (uub.RESULT_WARN, 'file contains "univention" incorrectly written'),
         }
 
-    RE_WHITEWORD = re.compile(r'|'.join(r"""
-        [0-9][0-9]univention
-        Xunivention
-        punivention
-        fBunivention
-        invention
-        [Kk]uhnivention
-        onvention
-        unintention
-        univention
-        Univention
-        UNIVENTION
-        _univention
-        univention_
-    """.split()))
+    RE_WHITEWORD = re.compile(r'|'.join([  # noqa: FLY002
+        r"[0-9][0-9]univention",
+        r"Xunivention",
+        r"punivention",
+        r"fBunivention",
+        r"invention",
+        r"[Kk]uhnivention",
+        r"onvention",
+        r"unintention",
+        r"univention",
+        r"Univention",
+        r"UNIVENTION",
+        r"_univention",
+        r"univention_",
+    ]))
 
-    RE_WHITELINE = re.compile(r'|'.join(r"""
-        \\[tnr]univention
-        -.univention
-        [SK]?[0-9][0-9]univention
-        univention[0-9]
-        univentionr\._baseconfig
-        /var/lib/univentions-client-boot/
-    """.split()))
+    RE_WHITELINE = re.compile(r'|'.join([  # noqa: FLY002
+        r"\\[tnr]univention",
+        r"-.univention",
+        r"[SK]?[0-9][0-9]univention",
+        r"univention[0-9]",
+        r"univentionr\._baseconfig",
+        r"/var/lib/univentions-client-boot/",
+    ]))
 
     def check(self, path: Path) -> None:
         super().check(path)
@@ -195,7 +168,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
                             found = match[0]
                             if self.RE_WHITEWORD.match(found):
                                 continue
-                            self.debug(f'{fn}:{row}: found="{found}"  origline="{origline}"')
+                            self.debug('%s:%s: found="%s"  origline="%s"', fn, row, found, origline)
                             self.addmsg('0015-2', f'univention is incorrectly spelled: {found}', fn, row)
             except UnicodeDecodeError:
                 # Silently skip binary files
