@@ -1,34 +1,7 @@
 #!/usr/bin/env python3
 #
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2008-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2008-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 from __future__ import annotations
 
@@ -41,6 +14,7 @@ from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     from collections.abc import Callable, Iterable, Iterator
+    from typing import Any
 
 
 try:
@@ -173,7 +147,7 @@ class UPCMessage:
 
         :returns: test case.
         """
-        tc = TestCase(self.id, stdout=self.msg, file=self.filename, line=self.row)  # FIXME
+        tc = TestCase(self.id, stdout=self.msg, file=self.filename, line=self.row)  # FIXME:
         return tc
 
 
@@ -214,14 +188,14 @@ class UniventionPackageCheckBase:
         """
         self.debuglevel = level
 
-    def debug(self, msg: str) -> None:
+    def debug(self, msg: str, *args: Any) -> None:
         """
         Print debug message.
 
         :param msg: Text string.
         """
         if self.debuglevel > 0:
-            print(f'{self.name}: {msg}')
+            print(f'{self.name}: {msg % args}')
 
     def postinit(self, path: Path) -> None:
         """
